@@ -178,7 +178,7 @@ class Demo(Style):
         cbo.pack(fill='x', pady=5)
 
         # Progressbar
-        ttk.Progressbar(widget_frame, variable=self.scale_var).pack(fill='x', pady=10)
+        ttk.Progressbar(widget_frame, variable=self.scale_var, style='Striped.Horizontal.TProgressbar').pack(fill='x', pady=10)
         return tab
 
     def run(self):
